@@ -11,9 +11,12 @@
 #include <random>
 #include <stdexcept>
 
+#include <tlx/define/endian.hpp>
 #include <tlx/die.hpp>
 #include <tlx/port/setenv.hpp>
 #include <tlx/string.hpp>
+#include <tlx/string/appendline.hpp>
+#include <tlx/string/ssprintf_generic.hpp>
 
 //! Returns an initialized unsigned char[] array inside an std::string
 #define ARRAY_AS_STRING(array) \
@@ -41,6 +44,39 @@ std::string random_binary(std::string::size_type size) {
     return out;
 }
 
+static void test_appendline() {
+    std::string input =
+        "abc\n" "def\n" "ghi\n" "jk";
+
+    std::stringstream ss1(input);
+    std::string line;
+
+    die_unless(tlx::appendline(ss1, line));
+    die_unequal(line, "abc");
+    die_unless(tlx::appendline(ss1, line));
+    die_unequal(line, "abcdef");
+    die_unless(tlx::appendline(ss1, line));
+    die_unequal(line, "abcdefghi");
+    die_unless(tlx::appendline(ss1, line));
+    die_unequal(line, "abcdefghijk");
+    die_if(tlx::appendline(ss1, line));
+
+    // add one last newline
+    input += "\n";
+    std::stringstream ss2(input);
+
+    line.clear();
+    die_unless(tlx::appendline(ss2, line));
+    die_unequal(line, "abc");
+    die_unless(tlx::appendline(ss2, line));
+    die_unequal(line, "abcdef");
+    die_unless(tlx::appendline(ss2, line));
+    die_unequal(line, "abcdefghi");
+    die_unless(tlx::appendline(ss2, line));
+    die_unequal(line, "abcdefghijk");
+    die_if(tlx::appendline(ss2, line));
+}
+
 static void test_base64() {
     // take some static hex data and dump it using base64 encoding, then decode
     // it again.
@@ -95,6 +131,43 @@ static void test_base64() {
         tlx::base64_decode("FjXKA5!!RxGFAudA"), std::runtime_error);
 }
 
+static void test_bitdump() {
+    die_unequal(tlx::bitdump_8_msb("0123"),
+                "00110000 00110001 00110010 00110011");
+    die_unequal(tlx::bitdump_8_lsb("0123"),
+                "00001100 10001100 01001100 11001100");
+
+#if TLX_LITTLE_ENDIAN
+    die_unequal(tlx::bitdump_8_msb_type(uint16_t(0x1234)),
+                "00110100 00010010");
+    die_unequal(tlx::bitdump_8_lsb_type(uint16_t(0x1234)),
+                "00101100 01001000");
+#else
+    die_unequal(tlx::bitdump_8_msb_type(uint16_t(0x1234)),
+                "00010010 00110100");
+    die_unequal(tlx::bitdump_8_lsb_type(uint16_t(0x1234)),
+                "01001000 00101100");
+#endif
+
+    // deprecated methods:
+    die_unequal(tlx::bitdump_le8("0123"),
+                "00110000 00110001 00110010 00110011");
+    die_unequal(tlx::bitdump_be8("0123"),
+                "00001100 10001100 01001100 11001100");
+
+#if TLX_LITTLE_ENDIAN
+    die_unequal(tlx::bitdump_le8_type(uint16_t(0x1234)),
+                "00110100 00010010");
+    die_unequal(tlx::bitdump_be8_type(uint16_t(0x1234)),
+                "00101100 01001000");
+#else
+    die_unequal(tlx::bitdump_le8_type(uint16_t(0x1234)),
+                "00010010 00110100");
+    die_unequal(tlx::bitdump_be8_type(uint16_t(0x1234)),
+                "01001000 00101100");
+#endif
+}
+
 static void test_compare_icase() {
     die_unless(std::string("ABC") != std::string("abc"));
 
@@ -202,6 +275,20 @@ static void test_format_si_iec_units() {
     die_unequal(tlx::format_iec_units(33 * 1024 * 1024 * 1024LLU), "33.000 Gi");
 }
 
+static void test_hash_djb2() {
+    die_unequal(
+        tlx::hash_djb2("hello hash me"), 0x2DA4090Fu);
+    die_unequal(
+        tlx::hash_djb2(std::string("hello hash me")), 0x2DA4090Fu);
+}
+
+static void test_hash_sdbm() {
+    die_unequal(
+        tlx::hash_sdbm("hello hash me"), 0x290130BCu);
+    die_unequal(
+        tlx::hash_sdbm(std::string("hello hash me")), 0x290130BCu);
+}
+
 static void test_hexdump() {
 
     // take hex data and dump it into a string, then parse back into array
@@ -512,6 +599,27 @@ static void test_split_words() {
     die_unequal(sv[4], "f  ");
 }
 
+static void test_ssprintf() {
+    die_unequal(
+        tlx::ssprintf("abc %d %s test", 42, "hello"),
+        "abc 42 hello test");
+    die_unequal(
+        tlx::ssnprintf(5, "abc %d %s test", 42, "hello"),
+        "abc 4");
+    die_unequal(
+        tlx::ssnprintf(5, "%d", 42), "42");
+
+    // "generic" version
+    die_unequal(
+        tlx::ssprintf_generic<std::string>("abc %d %s test", 42, "hello"),
+        "abc 42 hello test");
+    die_unequal(
+        tlx::ssnprintf_generic<std::string>(5, "abc %d %s test", 42, "hello"),
+        "abc 4");
+    die_unequal(
+        tlx::ssnprintf_generic<std::string>(5, "%d", 42), "42");
+}
+
 static void test_replace() {
     // copy variants
     die_unequal(
@@ -553,28 +661,36 @@ static void test_replace() {
         tlx::replace_all(&str2, "a", "aaa"), "aaabcdef aaabcdef");
 }
 
+template <typename TypeA, typename TypeB>
+void test_starts_with_ends_with_template() {
+
+    die_unless(tlx::starts_with(TypeA("abcdef"), TypeB("abc")));
+    die_unless(!tlx::starts_with(TypeA("abcdef"), TypeB("def")));
+    die_unless(tlx::ends_with(TypeA("abcdef"), TypeB("def")));
+    die_unless(!tlx::ends_with(TypeA("abcdef"), TypeB("abc")));
+
+    die_unless(!tlx::starts_with(TypeA("abcdef"), TypeB("ABC")));
+
+    die_unless(tlx::starts_with_icase(TypeA("abcdef"), TypeB("ABC")));
+    die_unless(!tlx::starts_with_icase(TypeA("abcdef"), TypeB("DEF")));
+    die_unless(tlx::ends_with_icase(TypeA("abcdef"), TypeB("DEF")));
+    die_unless(!tlx::ends_with_icase(TypeA("abcdef"), TypeB("ABC")));
+
+    die_unless(tlx::starts_with(TypeA("abcdef"), TypeB("")));
+    die_unless(tlx::ends_with(TypeA("abcdef"), TypeB("")));
+
+    die_unless(!tlx::starts_with(TypeA(""), TypeB("abc")));
+    die_unless(!tlx::ends_with(TypeA(""), TypeB("abc")));
+
+    die_unless(tlx::starts_with(TypeA(""), TypeB("")));
+    die_unless(tlx::ends_with(TypeA(""), TypeB("")));
+}
+
 static void test_starts_with_ends_with() {
-
-    die_unless(tlx::starts_with("abcdef", "abc"));
-    die_unless(!tlx::starts_with("abcdef", "def"));
-    die_unless(tlx::ends_with("abcdef", "def"));
-    die_unless(!tlx::ends_with("abcdef", "abc"));
-
-    die_unless(!tlx::starts_with("abcdef", "ABC"));
-
-    die_unless(tlx::starts_with_icase("abcdef", "ABC"));
-    die_unless(!tlx::starts_with_icase("abcdef", "DEF"));
-    die_unless(tlx::ends_with_icase("abcdef", "DEF"));
-    die_unless(!tlx::ends_with_icase("abcdef", "ABC"));
-
-    die_unless(tlx::starts_with("abcdef", ""));
-    die_unless(tlx::ends_with("abcdef", ""));
-
-    die_unless(!tlx::starts_with("", "abc"));
-    die_unless(!tlx::ends_with("", "abc"));
-
-    die_unless(tlx::starts_with("", ""));
-    die_unless(tlx::ends_with("", ""));
+    test_starts_with_ends_with_template<const char*, const char*>();
+    test_starts_with_ends_with_template<const char*, std::string>();
+    test_starts_with_ends_with_template<std::string, const char*>();
+    test_starts_with_ends_with_template<std::string, std::string>();
 }
 
 static void test_toupper_tolower() {
@@ -754,7 +870,9 @@ static void test_word_wrap() {
 
 int main() {
 
+    test_appendline();
     test_base64();
+    test_bitdump();
     test_compare_icase();
     test_contains_word();
     test_erase_all();
@@ -763,6 +881,8 @@ int main() {
     test_expand_environment_variables();
     test_extract_between();
     test_format_si_iec_units();
+    test_hash_djb2();
+    test_hash_sdbm();
     test_hexdump();
     test_join();
     test_levenshtein();
@@ -771,6 +891,7 @@ int main() {
     test_split();
     test_split_join_quoted();
     test_split_words();
+    test_ssprintf();
     test_starts_with_ends_with();
     test_toupper_tolower();
     test_trim();
