@@ -3,7 +3,7 @@
  *
  * Part of tlx - http://panthema.net/tlx
  *
- * Copyright (C) 2016-2018 Timo Bingmann <tb@panthema.net>
+ * Copyright (C) 2016-2020 Timo Bingmann <tb@panthema.net>
  *
  * All rights reserved. Published under the Boost Software License, Version 1.0
  ******************************************************************************/
@@ -14,7 +14,7 @@
 
 namespace tlx {
 
-// Windows porting madness because setenv() is apparently dangerous
+// Windows porting madness because setenv() is apparently dangerous.
 #if defined(_MSC_VER)
 
 int setenv(const char* name, const char* value, int overwrite) {
@@ -26,6 +26,17 @@ int setenv(const char* name, const char* value, int overwrite) {
     return _putenv_s(name, value);
 }
 
+// More porting weirdness for MinGW (32 and 64)
+#elif defined(__MINGW32__)
+
+int setenv(const char* name, const char* value, int overwrite) {
+    if (!overwrite) {
+        const char* current = getenv(name);
+        if (current) return 0;
+    }
+    return _putenv_s(name, value);
+}
+
 #else
 
 int setenv(const char* name, const char* value, int overwrite) {
