@@ -112,6 +112,13 @@ public:
         return values[idx];
     }
 
+    /**
+     * Assigns the given value to all the elements in the vector.
+     *
+     * @param val The value to be assigned.
+     */
+    void fill(double val) { std::fill(values.begin(), values.end(), val); }
+
     /**
      * Returns the element at index @a idx without checking the range of this vector.
      * @a idx The index of the element.
