@@ -4,6 +4,8 @@
 #include <cstdint>
 #include <exception>
 
+#include <tlx/define/deprecated.hpp>
+
 namespace Aux {
 
     class SignalHandler {
@@ -31,13 +33,13 @@ namespace SignalHandling {
          * Returns true, if CTRL+C/SIGINT has been received, false otherwise.
          * @return A boolean indicating if SIGINT has been received since construction/reset
          */
-        bool gotSIGINT();
+        bool TLX_DEPRECATED(gotSIGINT());
         
         /**
          * Sets the value of `receivedSIGINT`
          * @param received The new value for `receivedSIGINT`
          */
-        void setSIGINT(bool received);
+        void TLX_DEPRECATED(setSIGINT(bool received));
 
         /**
          * Registers the function `setRunning` to be invoked, when CTRL+C/SIGINT is received.
