@@ -5,6 +5,8 @@
 #include <networkit/centrality/Centrality.hpp>
 #include <networkit/structures/Partition.hpp>
 
+#include <tlx/define/deprecated.hpp>
+
 namespace NetworKit {
 
 /**
@@ -22,6 +24,7 @@ public:
 
     /**
      * Computes local partition coverage on the graph passed in constructor.
+     * This method runs in parallel.
      */
     void run() override;
 
@@ -36,13 +39,13 @@ public:
      * This algorithm is parallel.
      * @return true
      */
-    bool isParallel() const override;
+    bool TLX_DEPRECATED(isParallel() const override);
 
     /**
      * The name of this algorithm.
      * @return "Local partition coverage"
      */
-    std::string toString() const override;
+    std::string TLX_DEPRECATED(toString() const override);
 
 protected:
     const Partition& P;
