@@ -3,6 +3,8 @@
 
 #include <networkit/community/LocalPartitionEvaluation.hpp>
 
+#include <tlx/define/deprecated.hpp>
+
 namespace NetworKit {
 
 /**
@@ -25,7 +27,7 @@ public:
     using LocalPartitionEvaluation::LocalPartitionEvaluation;
 
     /**
-     * Execute the algorithm.
+     * Execute the algorithm. The algorithm is not parallel.
      */
     void run() override;
 
@@ -37,12 +39,12 @@ public:
     /**
      * @return false - this algorithm is not parallel.
      */
-    bool isParallel() const override { return false; };
+    bool TLX_DEPRECATED(isParallel() const override) { return false; };
 
     /**
      * Get the name of the algorithm.
      */
-    std::string toString() const override { return "Isolated inter-partition expansion"; };
+    std::string TLX_DEPRECATED(toString() const override) { return "Isolated inter-partition expansion"; };
 };
 
 }
