@@ -3,6 +3,8 @@
 
 #include <networkit/community/LocalPartitionEvaluation.hpp>
 
+#include <tlx/define/deprecated.hpp>
+
 namespace NetworKit {
 
 /**
@@ -22,7 +24,7 @@ public:
     using LocalPartitionEvaluation::LocalPartitionEvaluation;
 
     /**
-     * Execute the algorithm.
+     * Execute the algorithm. The algorithm is not parallel.
      */
     void run() override;
 
@@ -34,7 +36,7 @@ public:
     /**
      * @return false - this implementation is not paralle.
      */
-    bool isParallel() const override { return false; }
+    bool TLX_DEPRECATED(isParallel() const override) { return false; }
 };
 
 }
