@@ -12,6 +12,7 @@
 #include <networkit/graph/Graph.hpp>
 #include <networkit/structures/Partition.hpp>
 
+#include <tlx/define/deprecated.hpp>
 
 namespace NetworKit {
 
@@ -44,7 +45,7 @@ public:
     Assortativity(const Graph& G, const Partition& partition);
 
     /**
-    *
+    * Runs the algorithm. The algorithm is not parallel.
     */
     void run() override;
 
@@ -58,9 +59,9 @@ public:
      * Returns a string with the algorithm's name and its parameters, if there are any. Subclasses should override it.
      * @return The string representation of the algorithm.
      */
-    std::string toString() const override;
+    std::string TLX_DEPRECATED(toString() const override);
 
-    bool isParallel() const override;
+    bool TLX_DEPRECATED(isParallel() const override);
 
 
 private:
