@@ -25,7 +25,7 @@ public:
 
     void run() override;
 
-    std::string toString() const override;
+    std::string TLX_DEPRECATED(toString() const override);
 
     std::pair<count, count> getDiameter() const;
 
