@@ -13,8 +13,6 @@
 #include <networkit/Globals.hpp>
 #include <networkit/graph/Graph.hpp>
 
-#include <tlx/define/deprecated.hpp>
-
 namespace NetworKit {
 
 /*
@@ -45,7 +43,6 @@ namespace NetworKit {
 class GraphBuilder {
     count n;          //!< current number of nodes
     count selfloops;  //!< currently encountered number of self loops
-    std::string name; //!< name of the graph, if not set it will be G#ID
 
     bool weighted; //!< true if the graph will be weighted, false otherwise
     bool directed; //!< true if the graph will be directed, false otherwise
@@ -85,12 +82,6 @@ public:
 
     void reset(count n = 0);
 
-    /**
-     * Set name of graph to @a name.
-     * @param name The name.
-     */
-    void TLX_DEPRECATED(setName(std::string name)) { this->name = name; }
-
     /**
      * Returns <code>true</code> if this graph supports edge weights other
      * than 1.0.
