@@ -9,6 +9,7 @@
 #define NETWORKIT_INDEPENDENTSET_INDEPENDENT_SET_FINDER_HPP_
 
 #include <networkit/graph/Graph.hpp>
+#include <tlx/define/deprecated.hpp>
 
 namespace NetworKit {
 
@@ -36,7 +37,7 @@ public:
      * Get string representation of the algorithm.
      * @return The string representation of the algorithm.
      */
-    virtual std::string toString() const;
+    virtual std::string TLX_DEPRECATED(toString() const);
 
     /**
      * Checks whether a set is independent.
