@@ -1,8 +1,8 @@
 /*
- * UDegreeIndex.h
+ * UDegreeIndex.hpp
  *
  *  Created on: 01.04.2015
- *      Author: Kolja Esders (kolja.esders@student.kit.edu)
+ *      Author: Kolja Esders
  */
 
 #ifndef NETWORKIT_LINKPREDICTION_U_DEGREE_INDEX_HPP_
@@ -17,15 +17,16 @@ namespace NetworKit {
  *
  * Index that simply returns the degree of the first given node.
  */
-class UDegreeIndex : public LinkPredictor {
-private:
+class UDegreeIndex final : public LinkPredictor {
   /**
    * Returns the degree of the first node provided, namely @a u.
    * @param u First node
    * @param v Second node
    * @return the degree of the first node provided, namely @a u
    */
-  double runImpl(node u, node v) override;
+  double runImpl(node u, node) override {
+    return G->degree(u);
+  }
 
 public:
   using LinkPredictor::LinkPredictor;
