@@ -5,12 +5,12 @@
  *      Author: Christian Staudt
  */
 
+// networkit-format
+
 #ifndef NETWORKIT_MATCHING_LOCAL_MAX_MATCHER_HPP_
 #define NETWORKIT_MATCHING_LOCAL_MAX_MATCHER_HPP_
 
-#include <algorithm>
-#include <set>
-
+#include <networkit/graph/Graph.hpp>
 #include <networkit/matching/Matcher.hpp>
 
 namespace NetworKit {
@@ -22,11 +22,15 @@ namespace NetworKit {
  */
 class LocalMaxMatcher final : public Matcher {
 public:
+    /**
+     * @param G Undirected graph with for which the matching is computed.
+     */
+    LocalMaxMatcher(const Graph &G);
 
-    LocalMaxMatcher(const Graph& G);
-
+    /**
+     * Runs the algorithm.
+     */
     void run() override;
-
 };
 
 } /* namespace NetworKit */
