@@ -61,6 +61,38 @@ public:
                        count maxConvergenceTime = 5 * 60 * 1000,
                        count maxIterations = std::numeric_limits<count>::max()) override;
 
+    /**
+     * Abstract parallel solve function that computes and processes results using @a resultProcessor for the matrix currently setup and the right-hand sides (size of @a rhsSize) provided by @a rhsLoader.
+     * The maximum spent time for each system can be specified by @a maxConvergenceTime and the maximum number of iterations can be set
+     * by @a maxIterations.
+     * @param rhsLoader
+     * @param resultProcessor
+     * @param rhsSize
+     * @param maxConvergenceTime
+     * @param maxIterations
+     * @note If the solver does not support parallelism during solves, this function falls back to solving the systems sequentially.
+     */
+    template<typename RHSLoader, typename ResultProcessor>
+    void parallelSolve(const RHSLoader& rhsLoader, const ResultProcessor& resultProcessor, std::pair<count, count> rhsSize,
+                       count maxConvergenceTime = 5 * 60 * 1000,
+                       count maxIterations = std::numeric_limits<count>::max()) {
+        const index numThreads = omp_get_max_threads();
+        count n = rhsSize.first;
+        count m = rhsSize.second;
+        std::vector<Vector> results(numThreads, Vector(m));
+        std::vector<Vector> RHSs(numThreads, Vector(m));
+
+#pragma omp parallel for
+        for (omp_index i = 0; i < static_cast<omp_index>(n); ++i) {
+            index threadId = omp_get_thread_num();
+            const Vector& rhs = rhsLoader(i, RHSs[threadId]);
+            Vector& result = results[threadId];
+
+            this->solve(rhs, result, maxConvergenceTime, maxIterations);
+            resultProcessor(i, result);
+        }
+    }
+
 private:
     Matrix matrix;
     Preconditioner precond;
@@ -116,11 +148,6 @@ void ConjugateGradient<Matrix, Preconditioner>::parallelSolve(const std::vector<
     }
 }
 
-
-
-
-
-
 } /* namespace NetworKit */
 
 #endif // NETWORKIT_NUMERICS_CONJUGATE_GRADIENT_HPP_
