@@ -40,7 +40,7 @@ public:
      * @return The (approximate) solution to the system.
      */
     Vector relax(const Matrix &A, const Vector &b, const Vector &initialGuess,
-                 const count maxIterations = std::numeric_limits<count>::max()) const override;
+                 count maxIterations = std::numeric_limits<count>::max()) const override;
 
     /**
      * Utilizes Gauss-Seidel relaxations until the given number of @a maxIterations is reached or the relative residual
@@ -51,7 +51,7 @@ public:
      * @return The (approximate) solution to the system.
      */
     Vector relax(const Matrix &A, const Vector &b,
-                 const count maxIterations = std::numeric_limits<count>::max()) const override;
+                 count maxIterations = std::numeric_limits<count>::max()) const override;
 };
 
 template<class Matrix>
