@@ -26,8 +26,10 @@ public:
     Smoother() {}
     virtual ~Smoother(){}
 
-    virtual Vector relax(const Matrix& A, const Vector& b, const Vector& initialGuess, const count maxIterations = std::numeric_limits<count>::max()) const = 0;
-    virtual Vector relax(const Matrix& A, const Vector& b, const count maxIterations = std::numeric_limits<count>::max()) const = 0;
+    virtual Vector relax(const Matrix &A, const Vector &b, const Vector &initialGuess,
+                         count maxIterations = std::numeric_limits<count>::max()) const = 0;
+    virtual Vector relax(const Matrix &A, const Vector &b,
+                         count maxIterations = std::numeric_limits<count>::max()) const = 0;
 };
 
 } /* namespace NetworKit */
