@@ -12,6 +12,8 @@
 #include <networkit/base/Algorithm.hpp>
 #include <networkit/graph/Graph.hpp>
 
+#include <tlx/define/deprecated.hpp>
+
 namespace NetworKit {
 
 /**
@@ -47,7 +49,7 @@ public:
     ~DegreePreservingShuffle() override;
 
     /**
-     * Execute trades as configured in the constructor.
+     * Execute trades as configured in the constructor. The algorithm is parallel.
      * @warning This function has to be called exactly once before invoking getGraph()
      */
     void run() final;
@@ -66,9 +68,15 @@ public:
      */
     const std::vector<node> &getPermutation() const noexcept { return permutation; }
 
-    std::string toString() const final;
+    std::string TLX_DEPRECATED(toString() const final);
 
-    bool isParallel() const final { return true; }
+    bool TLX_DEPRECATED(isParallel() const final) { return true; }
+
+    static Graph shuffleGraph(const Graph &input) {
+        DegreePreservingShuffle algo(input);
+        algo.run();
+        return algo.getGraph();
+    }
 
 private:
     const Graph *G;
