@@ -1,3 +1,4 @@
+// networkit-format
 /*
  * ApproximatePageRank.hpp
  *
@@ -8,6 +9,7 @@
 #ifndef NETWORKIT_SCD_APPROXIMATE_PAGE_RANK_HPP_
 #define NETWORKIT_SCD_APPROXIMATE_PAGE_RANK_HPP_
 
+#include <set>
 #include <unordered_map>
 #include <vector>
 
@@ -19,11 +21,11 @@ namespace NetworKit {
  * Computes an approximate PageRank vector from a given seed.
  */
 class ApproximatePageRank final {
-    const Graph* G;
+    const Graph *g;
     double alpha;
     double eps;
 
-    std::unordered_map<node, std::pair<double, double>> pr_res;
+    std::unordered_map<node, std::pair<double, double>> prRes;
 
 public:
     /**
@@ -31,7 +33,13 @@ public:
      * @param alpha Loop probability of random walk.
      * @param epsilon Error tolerance.
      */
-    ApproximatePageRank(const Graph& g, double alpha, double epsilon = 1e-12);
+    ApproximatePageRank(const Graph &g, double alpha, double epsilon = 1e-12);
+
+    /**
+     * @return Approximate PageRank vector from @a seeds with parameters
+     *         specified in the constructor.
+     */
+    std::vector<std::pair<node, double>> run(const std::set<node> &seeds);
 
     /**
      * @return Approximate PageRank vector from @a seed with parameters
