@@ -1,3 +1,4 @@
+// networkit-format
 /*
  * PageRankNibble.hpp
  *
@@ -10,6 +11,7 @@
 
 #include <set>
 
+#include <tlx/define/deprecated.hpp>
 #include <networkit/graph/Graph.hpp>
 #include <networkit/scd/SelectiveCommunityDetector.hpp>
 
@@ -26,7 +28,7 @@ class PageRankNibble final : public SelectiveCommunityDetector {
     double alpha;
     double epsilon;
 
-    std::set<node> bestSweepSet(std::vector<std::pair<node, double>>& pr);
+    std::set<node> bestSweepSet(std::vector<std::pair<node, double>> &pr);
 
 public:
     /**
@@ -36,19 +38,30 @@ public:
      *        communities.
      * @param eps Tolerance threshold for approximation of PageRank vectors.
      */
-    PageRankNibble(const Graph& g, double alpha, double epsilon);
+    PageRankNibble(const Graph &g, double alpha, double epsilon);
 
     ~PageRankNibble() override = default;
 
-    std::map<node, std::set<node>> run(const std::set<node>& seeds) override;
+    /**
+     * Expand a node into a community.
+     *
+     * Deprecated, use PageRankNibble::expandOneCommunity instead.
+     *
+     * @param seed Seed node for which a community is to be found.
+     *
+     * @return Set of nodes that makes up the best community found around the @a seed node.
+     */
+    std::set<node> TLX_DEPRECATED(expandSeed(node seed));
 
     /**
-     * @param seed Seed node for which a community is to be found.
-
-     * @return Set of nodes that makes up the best community found around node @a seed.
-     *   If target conductance or target size are not fulfilled, an empty set is returned.
+     * @param seeds Seed nodes for which a community is to be found.
+     *
+     * @return Set of nodes that makes up the best community found around the @a seeds nodes.
      */
-    std::set<node> expandSeed(node seed);
+    std::set<node> expandOneCommunity(const std::set<node> &seeds) override;
+
+    // inherit method from parent class.
+    using SelectiveCommunityDetector::expandOneCommunity;
 };
 
 } /* namespace NetworKit */
