@@ -20,10 +20,14 @@ struct ListEntry {
 };
 
 ApproxCloseness::ApproxCloseness(const Graph& G, count nSamples, double epsilon, bool normalized, CLOSENESS_TYPE type) : Centrality(G, normalized), nSamples(nSamples), epsilon(epsilon), type(type) {
-    assert(nSamples > 0 && nSamples <= G.numberOfNodes() && epsilon >= 0);
+    assert(nSamples > 0 && epsilon >= 0);
 }
 
 void ApproxCloseness::run() {
+    if (nSamples > G.numberOfNodes()) {
+        WARN("Number of samples higher than the number of nodes. Setting number of samples to number of nodes");
+        nSamples = G.numberOfNodes();
+    }
     if (G.isDirected()) {
         switch (type) {
             case OUTBOUND:
@@ -64,17 +68,7 @@ void ApproxCloseness::run() {
 }
 
 void ApproxCloseness::estimateClosenessForUndirectedGraph() {
-    std::vector<node> sampledNodes;
-    // sample nodes
-    std::vector<bool> alreadySampled(G.upperNodeIdBound(), false);
-    for (count i = 0; i < nSamples; ++i) { // we have to sample distinct nodes
-        node v = GraphTools::randomNode(G);
-        while (alreadySampled[v]) {
-            v = GraphTools::randomNode(G);
-        }
-        sampledNodes.push_back(v);
-        alreadySampled[v] = true;
-    }
+    std::vector<node> sampledNodes = GraphTools::randomNodes(G, nSamples);
 
     LCSum = std::vector<double>(G.upperNodeIdBound());
     LCNum = std::vector<count>(G.upperNodeIdBound());
@@ -96,19 +90,23 @@ void ApproxCloseness::estimateClosenessForUndirectedGraph() {
 
     G.parallelForNodes([&](node u) {
         if (sampledNodes[pivot[u]] != u) { // exclude sampled nodes
-            count LNum = G.numberOfNodes() - 1 - HNum[u] - nSamples + LCNum[u];
+            const double LNum = static_cast<double>(G.numberOfNodes() - 1 - HNum[u] - nSamples + LCNum[u]);
             count HCNum = nSamples - LCNum[u];
 
             bool includeHCTerm = true;
             if (HCNum == 0) includeHCTerm = false;
 
-            double p = (double) LCNum[u] / (double) LNum;
+            double p = static_cast<double>(LCNum[u]) / LNum;
             scoreData[u] = HSum[u] + HCSum[u] + LCSum[u] / p;
-            double LCSqAvg = (LCSum[u] / (double) LCNum[u]) * (LCSum[u] / (double) LCNum[u]);
+            double LCSqAvg = (LCSum[u] / static_cast<double>(LCNum[u]))
+                             * (LCSum[u] / static_cast<double>(LCNum[u]));
             if (includeHCTerm) {
-                SQErrEst[u] = 1.0 / (double) LCNum[u] *  (LCSumSQ[u] / (double) LCNum[u] - LCSqAvg) * LNum + HCSumSQErr[u] / (double) HCNum * HNum[u];
+                SQErrEst[u] = 1.0 / static_cast<double>(LCNum[u])
+                                  * (LCSumSQ[u] / static_cast<double>(LCNum[u]) - LCSqAvg) * LNum
+                              + HCSumSQErr[u] / static_cast<double>(HCNum * HNum[u]);
             } else {
-                SQErrEst[u] = 1.0 / (double) LCNum[u] *  (LCSumSQ[u] / (double) LCNum[u] - LCSqAvg) * LNum;
+                SQErrEst[u] = 1.0 / static_cast<double>(LCNum[u])
+                              * (LCSumSQ[u] / static_cast<double>(LCNum[u]) - LCSqAvg) * LNum;
             }
 
         } else {
@@ -145,7 +143,7 @@ void ApproxCloseness::computeClosenessForDirectedWeightedGraph(bool outbound) {
         dist[u] = 0.0;
         round[u] = t;
         pq.insert(dist[u], u);
-        while (pq.size() > 0) {
+        while (!pq.empty()) {
             node v = pq.extractMin().second;
             if (dist[v] == infDist) break;
             if (count[v] < nSamples) {  // only continue if count[v] < k
@@ -273,7 +271,7 @@ void ApproxCloseness::computeClosestPivot(const std::vector<node> &samples, std:
         pivot[samples[i]] = i; // sample node is its own pivot
         pq.insert(0.0, samples[i]);
     }
-    while (pq.size() > 0) {
+    while (!pq.empty()) {
         node u = pq.extractMin().second;
         G.forNeighborsOf(u, [&](node v, edgeweight w) {
             if (delta[u] + w < delta[v]) {
@@ -291,7 +289,7 @@ void ApproxCloseness::runOnPivot(index i, const std::vector<node> &pivot, const
     orderNodesByIncreasingDistance(samples[i], order, pivotDist);
 
     std::vector<node> last(samples.size(), G.upperNodeIdBound());
-    std::vector<node> dist(samples.size());
+    std::vector<edgeweight> dist(samples.size());
 
     std::vector<std::vector<ListEntry>> list(samples.size());
     std::vector<std::vector<node>> nodes(G.upperNodeIdBound());
@@ -375,7 +373,7 @@ void ApproxCloseness::orderNodesByIncreasingDistance(node c, std::vector<node> &
         Aux::PrioQueue<edgeweight, node> pq(pivotDist.size());
         pq.insert(0.0, c);
         index idx = 0;
-        while (pq.size() > 0) {
+        while (!pq.empty()) {
             node u = pq.extractMin().second;
             order[idx++] = u;
             G.forNeighborsOf(u, [&](node v, edgeweight w) {
