@@ -32,7 +32,7 @@ void Sfigality::run() {
 
 double Sfigality::maximum() {
     throw std::runtime_error("Not Implemented");
-    return G.numberOfNodes() - 1;
+    return G.isEmpty() ? 0. : static_cast<double>(G.numberOfNodes() - 1);
 }
 
 
