@@ -20,6 +20,7 @@
 #include <networkit/centrality/Betweenness.hpp>
 #include <networkit/centrality/Closeness.hpp>
 #include <networkit/centrality/CoreDecomposition.hpp>
+#include <networkit/centrality/DegreeCentrality.hpp>
 #include <networkit/centrality/DynApproxBetweenness.hpp>
 #include <networkit/centrality/DynKatzCentrality.hpp>
 #include <networkit/centrality/DynTopHarmonicCloseness.hpp>
@@ -27,7 +28,11 @@
 #include <networkit/centrality/EstimateBetweenness.hpp>
 #include <networkit/centrality/GedWalk.hpp>
 #include <networkit/centrality/GroupCloseness.hpp>
+#include <networkit/centrality/GroupClosenessGrowShrink.hpp>
+#include <networkit/centrality/GroupClosenessLocalSwaps.hpp>
+#include <networkit/centrality/GroupClosenessLocalSearch.hpp>
 #include <networkit/centrality/GroupDegree.hpp>
+#include <networkit/centrality/GroupHarmonicCloseness.hpp>
 #include <networkit/centrality/HarmonicCloseness.hpp>
 #include <networkit/centrality/KPathCentrality.hpp>
 #include <networkit/centrality/KadabraBetweenness.hpp>
@@ -39,11 +44,15 @@
 #include <networkit/centrality/SpanningEdgeCentrality.hpp>
 #include <networkit/centrality/TopCloseness.hpp>
 #include <networkit/centrality/TopHarmonicCloseness.hpp>
+#include <networkit/components/ConnectedComponents.hpp>
 #include <networkit/distance/Dijkstra.hpp>
 #include <networkit/generators/DorogovtsevMendesGenerator.hpp>
 #include <networkit/generators/ErdosRenyiGenerator.hpp>
 #include <networkit/generators/HyperbolicGenerator.hpp>
 #include <networkit/graph/GraphTools.hpp>
+#include <networkit/graph/BFS.hpp>
+#include <networkit/graph/Dijkstra.hpp>
+#include <networkit/io/EdgeListReader.hpp>
 #include <networkit/io/METISGraphReader.hpp>
 #include <networkit/io/SNAPGraphReader.hpp>
 #include <networkit/structures/Cover.hpp>
@@ -57,10 +66,10 @@ protected:
     bool isWeighted() const noexcept;
 };
 
-INSTANTIATE_TEST_CASE_P(InstantiationName, CentralityGTest,
+INSTANTIATE_TEST_SUITE_P(InstantiationName, CentralityGTest,
         testing::Values(std::make_pair(false, false), std::make_pair(true, false),
                         std::make_pair(false, true),
-                        std::make_pair(true, true)), ); // comma required for variadic macro
+                        std::make_pair(true, true)));
 
 bool CentralityGTest::isWeighted() const noexcept { return GetParam().first; }
 
@@ -501,6 +510,34 @@ TEST_P(CentralityGTest, testPageRank) {
     doTest(PageRank::Norm::L2Norm);
 }
 
+TEST_P(CentralityGTest, testNormalizedPageRank) {
+    SNAPGraphReader reader(isDirected());
+    auto G = reader.read("input/wiki-Vote.txt");
+
+    auto doTest = [&G](PageRank::Norm norm) {
+        PageRank pr(G, 0.85, 1e-8, true);
+        pr.norm = norm;
+        pr.run();
+
+        auto pr_ranking = pr.ranking();
+        const double tol = 1e-4;
+        if (G.isDirected()) {
+            EXPECT_EQ(pr_ranking[0].first, 326);
+            EXPECT_NEAR(pr_ranking[0].second, 57.6657, tol);
+        } else {
+            EXPECT_EQ(pr_ranking[0].first, 699);
+            EXPECT_NEAR(pr_ranking[0].second, 205.7324, tol);
+        }
+        const count maxIterations = 2;
+        pr.maxIterations = maxIterations;
+        pr.run();
+        EXPECT_LE(pr.numberOfIterations(), maxIterations);
+    };
+
+    doTest(PageRank::Norm::L1Norm);
+    doTest(PageRank::Norm::L2Norm);
+}
+
 TEST_F(CentralityGTest, testEigenvectorCentrality) {
     /* Graph:
      0    3   6
@@ -584,6 +621,48 @@ TEST_F(CentralityGTest, testPageRankCentrality) {
     EXPECT_NEAR(0.0565, fabs(cen[7]), tol);
 }
 
+TEST_F(CentralityGTest, testNormalizedPageRankCentrality) {
+    /* Graph:
+     0    3   6
+      \  / \ /
+       2 -- 5
+      /  \ / \
+     1    4   7
+
+     Edges in the upper row have weight 3,
+     the edge in the middle row has weight 1.5,
+     edges in the lower row have weight 2.
+    */
+    count n = 8;
+    Graph G(n, true);
+
+    G.addEdge(0, 2, 3);
+    G.addEdge(1, 2, 2);
+    G.addEdge(2, 3, 3);
+    G.addEdge(2, 4, 2);
+    G.addEdge(2, 5, 1.5);
+    G.addEdge(3, 5, 3);
+    G.addEdge(4, 5, 2);
+    G.addEdge(5, 6, 3);
+    G.addEdge(5, 7, 2);
+
+    double damp = 0.85;
+    PageRank centrality(G, damp, 1e-8, true);
+    centrality.run();
+    std::vector<double> cen = centrality.scores();
+
+    // compare to Matlab results
+    const double tol = 1e-4;
+    EXPECT_NEAR(4.0175, fabs(cen[0]), tol);
+    EXPECT_NEAR(3.0117, fabs(cen[1]), tol);
+    EXPECT_NEAR(13.6083, fabs(cen[2]), tol);
+    EXPECT_NEAR(7.0350, fabs(cen[3]), tol);
+    EXPECT_NEAR(5.0233, fabs(cen[4]), tol);
+    EXPECT_NEAR(13.6083, fabs(cen[5]), tol);
+    EXPECT_NEAR(4.0175, fabs(cen[6]), tol);
+    EXPECT_NEAR(3.0117, fabs(cen[7]), tol);
+}
+
 TEST_F(CentralityGTest, benchSequentialBetweennessCentralityOnRealGraph) {
     METISGraphReader reader;
     Graph G = reader.read("input/celegans_metabolic.graph");
@@ -621,6 +700,16 @@ TEST_F(CentralityGTest, benchPageRankCentralityOnRealGraph) {
     INFO("Highest rank: ", ranking[0].first, " with score ", ranking[0].second);
 }
 
+TEST_F(CentralityGTest, benchNormalizedPageRankCentralityOnRealGraph) {
+    METISGraphReader reader;
+    Graph G = reader.read("input/celegans_metabolic.graph");
+    double damp = 0.85;
+    PageRank cen(G, damp, 1e-8, true);
+    cen.run();
+    std::vector<std::pair<node, double>> ranking = cen.ranking();
+    INFO("Highest rank: ", ranking[0].first, " with score ", ranking[0].second);
+}
+
 TEST_F(CentralityGTest, runEstimateBetweenness) {
     METISGraphReader reader;
     Graph G = reader.read("input/celegans_metabolic.graph");
@@ -1807,4 +1896,333 @@ TEST_F(CentralityGTest, testApproxElectricalCloseness) {
     }
 }
 
+TEST_P(CentralityGTest, testGroupClosenessGrowShrink) {
+    if (isDirected()) { // directed graphs are not supported
+        Graph G(10, isWeighted(), true);
+        std::array<node, 1> group;
+        EXPECT_THROW(GroupClosenessGrowShrink(G, group.begin(), group.end()), std::runtime_error);
+        return;
+    }
+
+    { // Empty input groups are not supported
+        Graph G(10, isWeighted(), false);
+        std::vector<node> emptyGroup;
+        EXPECT_THROW(GroupClosenessGrowShrink(G, emptyGroup.begin(), emptyGroup.end()),
+                     std::runtime_error);
+    }
+
+    const count k = 5;
+    auto G = EdgeListReader{'\t', 0, "#", false, false}.read("input/MIT8.edgelist");
+    G = ConnectedComponents::extractLargestConnectedComponent(G);
+
+    if (isWeighted()) {
+        G = GraphTools::toWeighted(G);
+        G.forEdges([&G](const node u, const node v) {
+            G.setWeight(u, v, Aux::Random::probability());
+        });
+    }
+
+    auto farnessOfGroup = [&](const Graph &G, const std::unordered_set<node> &group) -> edgeweight {
+        edgeweight farness = 0;
+        if (G.isWeighted()) {
+            Traversal::DijkstraFrom(
+                G, group.begin(), group.end(),
+                [&farness](node, const edgeweight distance) { farness += distance; });
+        } else {
+            Traversal::BFSfrom(
+                G, group.begin(), group.end(),
+                [&farness](node, const edgeweight distance) { farness += distance; });
+        }
+
+        return farness;
+    };
+
+    for (int seed : {1, 2, 3}) {
+        Aux::Random::setSeed(seed, true);
+
+        std::unordered_set<node> group;
+
+        do {
+            group.insert(GraphTools::randomNode(G));
+        } while (group.size() < k);
+
+        edgeweight sumDist = farnessOfGroup(G, group);
+        GroupClosenessGrowShrink gc(G, group.begin(), group.end());
+        gc.run();
+        auto groupMaxCC = gc.groupMaxCloseness();
+        count nSwaps = gc.numberOfIterations();
+
+        EXPECT_EQ(groupMaxCC.size(), k);
+
+        edgeweight sumDistGroupMaxCC =
+            farnessOfGroup(G, std::unordered_set<node>(groupMaxCC.begin(), groupMaxCC.end()));
+        if (nSwaps > 0) {
+            EXPECT_GE(sumDist, sumDistGroupMaxCC);
+        } else {
+            EXPECT_EQ(sumDist, sumDistGroupMaxCC);
+            std::for_each(groupMaxCC.begin(), groupMaxCC.end(), [&group](const node u) {
+                EXPECT_NE(group.find(u), group.end());
+            });
+        }
+    }
+}
+
+
+TEST_P(CentralityGTest, testDegreeCentrality) {
+    Graph g(8, false, isDirected());
+
+    g.addEdge(0, 2);
+    g.addEdge(0, 5);
+    g.addEdge(1, 2);
+    g.addEdge(2, 3);
+    g.addEdge(2, 2);
+    g.addEdge(2, 4);
+    g.addEdge(3, 5);
+    g.addEdge(4, 5);
+    g.addEdge(5, 5);
+    g.addEdge(5, 6);
+    g.addEdge(5, 7);
+    g.addEdge(7, 7);
+
+    DegreeCentrality dc(g, false, true, false);
+    dc.run();
+
+    if (isDirected()){
+        std::array<int ,8> expectedResults{{2, 1, 3, 1, 1, 3, 0, 1}};
+        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    } else {
+        std::array<int ,8> expectedResults{{2, 1, 5, 2, 2, 6, 1, 2}};
+        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    }
+}
+
+TEST_P(CentralityGTest, testInDegreeCentrality) {
+    Graph g(8, false, isDirected());
+
+    g.addEdge(0, 2);
+    g.addEdge(0, 5);
+    g.addEdge(1, 2);
+    g.addEdge(2, 3);
+    g.addEdge(2, 2);
+    g.addEdge(2, 4);
+    g.addEdge(3, 5);
+    g.addEdge(4, 5);
+    g.addEdge(5, 5);
+    g.addEdge(5, 6);
+    g.addEdge(5, 7);
+    g.addEdge(7, 7);
+
+    DegreeCentrality dc(g, false, false, false);
+    dc.run();
+
+    if (isDirected()){
+        std::array<int ,8> expectedResults{{0, 0, 3, 1, 1, 4, 1, 2}};
+        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    } else {
+        std::array<int ,8> expectedResults{{2, 1, 5, 2, 2, 6, 1, 2}};
+        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    }
+}
+
+TEST_P(CentralityGTest, testDegreeCentralityIgnoreSelfLoops) {
+    Graph g(8, false, isDirected());
+
+    g.addEdge(0, 2);
+    g.addEdge(0, 5);
+    g.addEdge(1, 2);
+    g.addEdge(2, 3);
+    g.addEdge(2, 2);
+    g.addEdge(2, 4);
+    g.addEdge(3, 5);
+    g.addEdge(4, 5);
+    g.addEdge(5, 5);
+    g.addEdge(5, 6);
+    g.addEdge(5, 7);
+    g.addEdge(7, 7);
+
+    DegreeCentrality dc(g, false, true, true);
+    dc.run();
+
+    if (isDirected()){
+        std::array<int ,8> expectedResults{{2, 1, 2, 1, 1, 2, 0, 0}};
+        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    } else {
+        std::array<int ,8> expectedResults{{2, 1, 4, 2, 2, 5, 1, 1}};
+        for(long unsigned int i = 0; i < expectedResults.size(); i++) EXPECT_EQ(expectedResults[i], dc.score(i));
+    }
+}
+
+TEST_P(CentralityGTest, testGroupClosenessLocalSwaps) {
+    if (isDirected()) { // directed graphs are not supported
+        Graph G(10, isWeighted(), true);
+        std::array<node, 1> group;
+        EXPECT_THROW(GroupClosenessLocalSwaps(G, group.begin(), group.end()), std::runtime_error);
+        return;
+    }
+
+    { // Empty input groups are not supported
+        Graph G(10, isWeighted(), false);
+        std::vector<node> emptyGroup;
+        EXPECT_THROW(GroupClosenessLocalSwaps(G, emptyGroup.begin(), emptyGroup.end()), std::runtime_error);
+    }
+
+    const count k = 5;
+    auto G = EdgeListReader{'\t', 0, "#", false, false}.read("input/MIT8.edgelist");
+    G = ConnectedComponents::extractLargestConnectedComponent(G);
+
+    if (isWeighted()) {
+        G = GraphTools::toWeighted(G);
+        G.forEdges([&G](const node u, const node v) {
+            G.setWeight(u, v, Aux::Random::probability());
+        });
+    }
+
+    auto farnessOfGroup = [&](const Graph &G, const std::unordered_set<node> &group) -> count {
+        count farness = 0;
+        Traversal::BFSfrom(G, group.begin(), group.end(),
+                           [&farness](node, count distance) { farness += distance; });
+
+        return farness;
+    };
+
+    for (int seed : {1, 2, 3}) {
+        Aux::Random::setSeed(seed, true);
+
+        std::unordered_set<node> group;
+
+        do {
+            group.insert(GraphTools::randomNode(G));
+        } while (group.size() < k);
+
+        const count maxSwaps = 100;
+        const count sumDist = farnessOfGroup(G, group);
+        GroupClosenessLocalSwaps gc(G, group.begin(), group.end(), maxSwaps);
+        gc.run();
+        auto groupMaxCC = gc.groupMaxCloseness();
+        const count nSwaps = gc.numberOfSwaps();
+
+        EXPECT_LE(nSwaps, maxSwaps);
+        EXPECT_EQ(groupMaxCC.size(), k);
+
+        count sumDistGroupMaxCC =
+            farnessOfGroup(G, std::unordered_set<node>(groupMaxCC.begin(), groupMaxCC.end()));
+
+        if (nSwaps > 0) {
+            EXPECT_GE(sumDist, sumDistGroupMaxCC);
+        } else {
+            EXPECT_EQ(sumDist, sumDistGroupMaxCC);
+            std::for_each(groupMaxCC.begin(), groupMaxCC.end(), [&group](const node u) {
+                EXPECT_NE(group.find(u), group.end());
+            });
+
+        }
+    }
+}
+
+TEST_P(CentralityGTest, testGroupHarmonicCloseness) {
+
+    const auto computeOpt = [&](const Graph &G, count k) -> double {
+        std::vector<bool> inGroup(G.upperNodeIdBound());
+        std::fill(inGroup.begin(), inGroup.begin() + k, true);
+        double opt = -std::numeric_limits<double>::max();
+        std::vector<node> group;
+        group.reserve(k);
+        do {
+            group.clear();
+            G.forNodes([&](node u) {
+                if (inGroup[u])
+                    group.push_back(u);
+            });
+            opt = std::max(opt, GroupHarmonicCloseness::scoreOfGroup(G, group.begin(), group.end()));
+        } while (std::prev_permutation(inGroup.begin(), inGroup.end()));
+
+        return opt;
+    };
+
+    const double weightUB = 10;
+    for (const int seed : {1, 2, 3}) {
+        Aux::Random::setSeed(seed, true);
+        auto G = ErdosRenyiGenerator(20, 0.1, isDirected()).generate();
+        double lambda = 1;
+
+        if (isWeighted()) {
+            double maxWeight = 0, minWeight = weightUB;
+            G = GraphTools::toWeighted(G);
+            G.forEdges([&](node u, node v) {
+                const double curWeight = Aux::Random::real(0.001, weightUB);
+                maxWeight = std::max(maxWeight, curWeight);
+                minWeight = std::min(minWeight, curWeight);
+                G.setWeight(u, v, curWeight);
+            });
+            lambda = minWeight / maxWeight;
+        }
+
+        // Guaranted approximation ratio
+        double approxRatio;
+        if (isDirected())
+            approxRatio = lambda * (1. - 1. / (2. * std::exp(1.)));
+        else
+            approxRatio = lambda * (1. - 1. / std::exp(1.)) / 2.;
+
+        for (const count k : {3, 4, 5}) {
+            GroupHarmonicCloseness ghc(G, k);
+            ghc.run();
+            const auto group = ghc.groupMaxHarmonicCloseness();
+
+            // Test group
+            EXPECT_EQ(group.size(), k);
+            EXPECT_EQ(std::unordered_set<node>(group.begin(), group.end()).size(), k);
+
+            // Test quality
+            const double score = GroupHarmonicCloseness::scoreOfGroup(G, group.begin(), group.end());
+            const double opt = computeOpt(G, k);
+            EXPECT_GE(opt, score);
+            EXPECT_GE(score / opt, approxRatio);
+        }
+    }
+}
+
+TEST_P(CentralityGTest, testGroupClosenessLocalSearch) {
+    { // Empty groups are not allowed
+        std::vector<node> emptyVector;
+        Graph G(10, isWeighted(), isDirected());
+        EXPECT_THROW(GroupClosenessLocalSearch(G, emptyVector.begin(), emptyVector.end()),
+                     std::runtime_error);
+    }
+
+    const auto groupCloseness = [&](const Graph &G, const std::vector<node> &group) -> edgeweight {
+        edgeweight groupFarness = 0;
+        Traversal::DijkstraFrom(G, group.begin(), group.end(),
+                                [&groupFarness](node, edgeweight dist) { groupFarness += dist; });
+        return groupFarness > 0 ? 1. / groupFarness : 0;
+    };
+
+    Aux::Random::setSeed(1, true);
+    auto G = ErdosRenyiGenerator(100, 0.1, isDirected()).generate();
+    if (isWeighted()) {
+        G = GraphTools::toWeighted(G);
+        G.forEdges([&](node u, node v) { G.setWeight(u, v, Aux::Random::real(10)); });
+    }
+
+    std::unordered_set<node> initGroup;
+    const count k = 5;
+    do {
+        initGroup.insert(GraphTools::randomNode(G));
+    } while (initGroup.size() < k);
+
+    const auto initGC = groupCloseness(G, std::vector<node>{initGroup.begin(), initGroup.end()});
+
+    GroupClosenessLocalSearch gcls(G, initGroup.begin(), initGroup.end(), !G.isDirected());
+    gcls.run();
+
+    const auto group = gcls.groupMaxCloseness();
+    EXPECT_EQ(std::unordered_set<node>(group.begin(), group.end()).size(), k);
+    EXPECT_GE(groupCloseness(G, group), initGC);
+
+    GroupClosenessLocalSearch gcls2(G, group, false);
+    gcls2.run();
+
+    EXPECT_EQ(gcls2.numberOfIterations(), 0);
+}
+
 } /* namespace NetworKit */
