@@ -2,7 +2,7 @@
  * MatchingCoarsening.cpp
  *
  *  Created on: 30.10.2012
- *      Author: Christian Staudt (christian.staudt@kit.edu)
+ *      Author: Christian Staudt
  */
 
 #include <networkit/coarsening/MatchingCoarsening.hpp>
@@ -14,15 +14,15 @@ MatchingCoarsening::MatchingCoarsening(const Graph& G, const Matching& M, bool n
 }
 
 void MatchingCoarsening::run() {
-    count n = G.numberOfNodes();
-    index z = G.upperNodeIdBound();
-    count cn = n - M.size(G);
+    count n = G->numberOfNodes();
+    index z = G->upperNodeIdBound();
+    count cn = n - M.size(*G);
     Graph cG(cn, true);
 
     // compute map: old ID -> new coarse ID
     index idx = 0;
     std::vector<node> mapFineToCoarse(z, none);
-    G.forNodes([&](node v) { // TODO: difficult in parallel
+    G->forNodes([&](node v) { // TODO: difficult in parallel
         index mate = M.mate(v);
         if (mate == v) DEBUG("Node ", v, " is its own matching!");
         assert(mate != v);
@@ -39,8 +39,8 @@ void MatchingCoarsening::run() {
         assert(mapFineToCoarse[v] < cn);
     });
 
-    G.forNodes([&](node v) { // TODO: difficult in parallel
-        G.forNeighborsOf(v, [&](node u, edgeweight ew) {
+    G->forNodes([&](node v) { // TODO: difficult in parallel
+        G->forNeighborsOf(v, [&](node u, edgeweight ew) {
             node cv = mapFineToCoarse[v];
             node cu = mapFineToCoarse[u];
             if ((v <= u) && (! noSelfLoops || (cv != cu))) {
