@@ -16,8 +16,8 @@ CommunityDetectionAlgorithm::CommunityDetectionAlgorithm(const Graph& G) : Algor
     }
 }
 
-CommunityDetectionAlgorithm::CommunityDetectionAlgorithm(const Graph& G, const Partition baseClustering) : Algorithm(), G(&G), result(baseClustering) {
-}
+CommunityDetectionAlgorithm::CommunityDetectionAlgorithm(const Graph &G, Partition baseClustering)
+    : Algorithm(), G(&G), result(std::move(baseClustering)) {}
 
 Partition CommunityDetectionAlgorithm::getPartition() {
     if(!hasRun) {
