@@ -16,19 +16,15 @@ BFS::BFS(const Graph &G, node source, bool storePaths,
     : SSSP(G, source, storePaths, storeNodesSortedByDistance, target) {}
 
 void BFS::run() {
-    count z = G.upperNodeIdBound();
+    count z = G->upperNodeIdBound();
     reachedNodes = 1;
     sumDist = 0.;
 
-    if (distances.size() < z) {
-        distances.resize(z, std::numeric_limits<edgeweight>::max());
-        visited.resize(z, ts);
-    }
+    const auto infDist = std::numeric_limits<edgeweight>::max();
+    std::fill(distances.begin(), distances.end(), infDist);
 
-    if (ts++ == 255) {
-        ts = 1;
-        std::fill(visited.begin(), visited.end(), 0);
-    }
+    if (distances.size() < z) 
+        distances.resize(z, infDist);
 
     if (storePaths) {
         previous.clear();
@@ -46,7 +42,6 @@ void BFS::run() {
     std::queue<node> q;
     q.push(source);
     distances[source] = 0.;
-    visited[source] = ts;
 
     bool breakWhenFound = (target != none);
     while (!q.empty()) {
@@ -60,16 +55,10 @@ void BFS::run() {
             break;
         }
 
-        // TRACE("current node in BFS: " , u);
-        //		TRACE(distances);
-
         // insert untouched neighbors into queue
-        G.forNeighborsOf(u, [&](node v) {
-            // TRACE("scanning neighbor ", v);
-
-            if (ts != visited[v]) {
+        G->forNeighborsOf(u, [&](node v) {
+            if (distances[v] == infDist) {
                 q.push(v);
-                visited[v] = ts;
                 distances[v] = distances[u] + 1.;
                 sumDist += distances[v];
                 ++reachedNodes;
