@@ -45,7 +45,7 @@ void BidirectionalBFS::run() {
     visited[target] = ts + ballMask;
 
     bool stop = false;
-    node s, t;
+    node s = none, t = none;
 
     // Expands a ball of a level; idx is the ball index (either 0 or 1<<7)
     auto expand = [&](std::queue<node> &q, std::queue<node> &q_, uint8_t idx) {
@@ -94,12 +94,14 @@ void BidirectionalBFS::run() {
             expand(sQueue, sQueueNext, 0);
         else
             expand(tQueue, tQueueNext, ballMask);
-    } while (!stop && sQueue.size() && tQueue.size());
+    } while (!stop && !sQueue.empty() && !tQueue.empty());
 
     // Balls did not meet, source cannot reach target
     if (!stop)
         stDist = std::numeric_limits<count>::max();
     else if (storePred) {
+        assert(s != none);
+        assert(t != none);
 
         // Reverse predecessors to target
         node t1 = pred[t];
