@@ -4,33 +4,32 @@
 *  Created on: 30.03.2016
 *      Author: Maximilian Vogel
 */
-
-#include <networkit/distance/NeighborhoodFunction.hpp>
-#include <networkit/components/ConnectedComponents.hpp>
-#include <networkit/auxiliary/Random.hpp>
-#include <networkit/graph/BFS.hpp>
-
-#include <math.h>
-#include <iterator>
-#include <stdlib.h>
-#include <omp.h>
+#include <cmath>
 #include <map>
+#include <omp.h>
+
+#include <networkit/auxiliary/Random.hpp>
+#include <networkit/components/ConnectedComponents.hpp>
+#include <networkit/distance/NeighborhoodFunction.hpp>
+#include <networkit/graph/BFS.hpp>
 
 namespace NetworKit {
 
-NeighborhoodFunction::NeighborhoodFunction(const Graph& G) : Algorithm(), G(G) {
-    if (G.isDirected()) throw std::runtime_error("current implementation can only deal with undirected graphs");
+NeighborhoodFunction::NeighborhoodFunction(const Graph& G) : Algorithm(), G(&G) {
+    if (G.isDirected())
+        throw std::runtime_error("current implementation can only deal with undirected graphs");
     ConnectedComponents cc(G);
     cc.run();
-    if (cc.getPartition().numberOfSubsets() > 1) throw std::runtime_error("current implementation only runs on graphs with 1 connected component");
+    if (cc.numberOfComponents() > 1) 
+        throw std::runtime_error("current implementation only runs on graphs with 1 connected component");
 }
 
 void NeighborhoodFunction::run() {
     count max_threads = (count)omp_get_max_threads();
     std::vector<std::map<count, count>> nf(max_threads);
-    G.parallelForNodes([&](node u){
+    G->parallelForNodes([&](node u){
         index tid = omp_get_thread_num();
-        Traversal::BFSfrom(G, u, [&](node, count dist) {
+        Traversal::BFSfrom(*G, u, [&](node, count dist) {
             nf[tid][dist] += 1;
         });
     });
@@ -59,5 +58,4 @@ std::vector<count> NeighborhoodFunction::getNeighborhoodFunction() const {
     return result;
 }
 
-
-}
+} // namespace NetworKit
