@@ -10,9 +10,7 @@
 
 namespace NetworKit {
 
-
-GraphEventProxy::GraphEventProxy() {
-}
+GraphEventProxy::GraphEventProxy() {}
 
 GraphEventProxy::GraphEventProxy(Graph& G) {
     this->G = &G;
@@ -20,7 +18,6 @@ GraphEventProxy::GraphEventProxy(Graph& G) {
 
 node GraphEventProxy::addNode() {
     node u = this->G->addNode();
-//	TRACE("adding node " , u);
     for (GraphEventHandler* observer : this->observers) {
         observer->onNodeAddition(u);
     }
@@ -29,7 +26,6 @@ node GraphEventProxy::addNode() {
 
 void GraphEventProxy::removeNode(node u) {
     this->G->removeNode(u);
-//	TRACE("removing node " , u);
     for (GraphEventHandler* observer : this->observers) {
         observer->onNodeRemoval(u);
     }
@@ -37,21 +33,18 @@ void GraphEventProxy::removeNode(node u) {
 
 void GraphEventProxy::restoreNode(node u) {
     this->G->restoreNode(u);
-//	TRACE("restoring node " , u);
     for (GraphEventHandler* observer : this->observers) {
         observer->onNodeRestoration(u);
     }
 }
 void GraphEventProxy::addEdge(node u, node v, edgeweight weight) {
     this->G->addEdge(u, v, weight);
-//	TRACE("adding edge (" , u , "," , v , ")");
     for (GraphEventHandler* observer : this->observers) {
         observer->onEdgeAddition(u, v);
     }
 }
 
 void GraphEventProxy::removeEdge(node u, node v) {
-//	TRACE("removing edge (" , u , "," , v , ")");
     this->G->removeEdge(u, v);
     for (GraphEventHandler* observer : this->observers) {
         observer->onEdgeRemoval(u, v);
@@ -60,7 +53,6 @@ void GraphEventProxy::removeEdge(node u, node v) {
 
 
 void GraphEventProxy::setWeight(node u, node v, edgeweight w) {
-//	TRACE("setting weight of edge (" , u , "," , v , ") to " , w);
     edgeweight wOld = this->G->weight(u, v);
     this->G->setWeight(u, v, w);
     for (GraphEventHandler* observer : this->observers) {
@@ -69,7 +61,6 @@ void GraphEventProxy::setWeight(node u, node v, edgeweight w) {
 }
 
 void GraphEventProxy::incrementWeight(node u, node v, edgeweight delta) {
-//	TRACE("incrementing weight of edge (" , u , "," , v , ") by " , delta);
     edgeweight wOld = this->G->weight(u, v);
     this->G->setWeight(u, v, wOld+delta);
     for (GraphEventHandler* observer : this->observers) {
@@ -79,7 +70,6 @@ void GraphEventProxy::incrementWeight(node u, node v, edgeweight delta) {
 
 void GraphEventProxy::timeStep() {
     WARN("GraphEventProxy::timeStep is deprecated and will not be supported in future releases.");
-//	TRACE("time step");
     // increment time step counter in G
     this->G->timeStep();
     for (GraphEventHandler* observer : this->observers) {
@@ -91,6 +81,4 @@ void GraphEventProxy::registerObserver(GraphEventHandler* observer) {
     this->observers.push_back(observer);
 }
 
-
-
 } /* namespace NetworKit */
