@@ -10,23 +10,23 @@
 namespace NetworKit {
 
 EdgeScoreAsWeight::EdgeScoreAsWeight(const Graph& G, const std::vector<double>& score, bool squared, edgeweight offset, edgeweight factor) :
-        G(G), score(score), squared(squared), offset(offset), factor(factor) {
+        G(&G), score(&score), squared(squared), offset(offset), factor(factor) {
 }
 
 Graph EdgeScoreAsWeight::calculate() {
-    if (!G.hasEdgeIds()) {
+    if (!G->hasEdgeIds()) {
         throw std::runtime_error("edges have not been indexed - call indexEdges first");
     }
 
-    Graph result(G, true, false);
+    Graph result(*G, true, false);
 
     if (squared) {
-        G.parallelForEdges([&](node u, node v, edgeid eid) {
-            result.setWeight(u, v, offset + factor * score[eid] * score[eid]);
+        G->parallelForEdges([&](node u, node v, edgeid eid) {
+            result.setWeight(u, v, offset + factor * (*score)[eid] * (*score)[eid]);
         });
     } else {
-        G.parallelForEdges([&](node u, node v, edgeid eid) {
-            result.setWeight(u, v, offset + factor * score[eid]);
+        G->parallelForEdges([&](node u, node v, edgeid eid) {
+            result.setWeight(u, v, offset + factor * (*score)[eid]);
         });
     }
 
