@@ -74,6 +74,46 @@ node randomNode(const Graph &G) {
     return v;
 }
 
+std::vector<node> randomNodes(const Graph &G, count n) {
+    assert(n <= G.numberOfNodes());
+    std::vector<node> selectedNodes;
+    std::vector<bool> alreadySelected(G.numberOfNodes(), false);
+
+    if (n == G.numberOfNodes()) {
+        selectedNodes.insert(selectedNodes.begin(), G.nodeRange().begin(), G.nodeRange().end());
+    } else if (n > G.numberOfNodes() / 2) { // in order to minimize the calls to randomNode
+                                            // we randomize the ones that aren't pivot
+                                            // if the are more to be selected than not-selected
+        std::fill(alreadySelected.begin(), alreadySelected.end(), true);
+
+        for (count i = 0; i < G.numberOfNodes() - n; ++i) { // we have to sample distinct nodes
+            node v = GraphTools::randomNode(G);
+            while (!alreadySelected[v]) {
+                v = GraphTools::randomNode(G);
+            }
+            alreadySelected[v] = false;
+        }
+
+        for (const auto sample : G.nodeRange()) {
+            if (alreadySelected[sample]) {
+                selectedNodes.push_back(sample);
+                if (selectedNodes.size() == n)
+                    break;
+            }
+        }
+    } else {
+        for (count i = 0; i < n; ++i) { // we have to selected distinct nodes
+            node v = GraphTools::randomNode(G);
+            while (alreadySelected[v]) {
+                v = GraphTools::randomNode(G);
+            }
+            selectedNodes.push_back(v);
+            alreadySelected[v] = true;
+        }
+    }
+    return selectedNodes;
+}
+
 std::pair<node, node> randomEdge(const Graph &G, bool uniformDistribution) {
     if (!G.numberOfEdges()) {
         throw std::runtime_error("Error: the graph has no edges!");
@@ -219,8 +259,17 @@ Graph copyNodes(const Graph &G) {
     return C;
 }
 
+Graph subgraphFromNodes(const Graph &G, const std::unordered_set<node> &nodes) {
+    return subgraphFromNodes(G, nodes.begin(), nodes.end(), false);
+}
+
 Graph subgraphFromNodes(const Graph &G, const std::unordered_set<node> &nodes,
                         bool includeOutNeighbors, bool includeInNeighbors) {
+    return subgraphAndNeighborsFromNodes(G, nodes, includeOutNeighbors, includeInNeighbors);
+}
+
+Graph subgraphAndNeighborsFromNodes(const Graph &G, const std::unordered_set<node> &nodes,
+                                    bool includeOutNeighbors, bool includeInNeighbors) {
     const auto neighbors = [&] {
         std::unordered_set<node> neighbors;
 
@@ -441,5 +490,20 @@ Graph restoreGraph(const std::vector<node> &invertedIdMap, const Graph &G) {
     return Goriginal;
 }
 
+void sortEdgesByWeight(Graph &G, bool decreasing) {
+    if (decreasing)
+        G.sortEdges([](auto e1, auto e2) {
+            if (e1.weight == e2.weight)
+                return e1.v < e2.v;
+            return e1.weight > e2.weight;
+        });
+    else
+        G.sortEdges([](auto e1, auto e2) {
+            if (e1.weight == e2.weight)
+                return e1.v < e2.v;
+            return e1.weight < e2.weight;
+        });
+}
+
 } // namespace GraphTools
 } // namespace NetworKit
