@@ -42,7 +42,7 @@ protected:
     Graph toGraph(GraphBuilder& b) const;
 };
 
-INSTANTIATE_TEST_CASE_P(InstantiationName, GraphBuilderAutoCompleteGTest, testing::Values(
+INSTANTIATE_TEST_SUITE_P(InstantiationName, GraphBuilderAutoCompleteGTest, testing::Values(
     std::make_tuple(false, false, false), // weighted, directed, parallel
     std::make_tuple(true, false, false),
     std::make_tuple(false, true, false),
@@ -52,7 +52,7 @@ INSTANTIATE_TEST_CASE_P(InstantiationName, GraphBuilderAutoCompleteGTest, testin
     std::make_tuple(true, false, true),
     std::make_tuple(false, true, true),
     std::make_tuple(true, true, true)
-), ); // comma required for variadic macro
+));
 
 bool GraphBuilderAutoCompleteGTest::isWeighted() const {
     return std::get<0>(GetParam());
@@ -482,10 +482,9 @@ TEST_P(GraphBuilderAutoCompleteGTest, testForNodes) {
 }
 
 TEST_P(GraphBuilderAutoCompleteGTest, testParallelForNodes) {
-    std::vector<node> visited;
+    std::vector<node> visited(bHouse.upperNodeIdBound());
     this->bHouse.parallelForNodes([&](node u) {
-        #pragma omp critical
-        visited.push_back(u);
+        visited[u] = u;
     });
 
     Aux::Parallel::sort(visited.begin(), visited.end());
