@@ -42,12 +42,12 @@ protected:
     Graph toGraph(GraphBuilder& b) const;
 };
 
-INSTANTIATE_TEST_CASE_P(InstantiationName, GraphBuilderDirectSwapGTest, testing::Values(
+INSTANTIATE_TEST_SUITE_P(InstantiationName, GraphBuilderDirectSwapGTest, testing::Values(
     std::make_tuple(false, false),
     std::make_tuple(true, false),
     std::make_tuple(false, true),
     std::make_tuple(false, false)
-), ); // comma required for variadic macro
+));
 
 bool GraphBuilderDirectSwapGTest::isWeighted() const {
     return std::get<0>(GetParam());
@@ -527,10 +527,9 @@ TEST_P(GraphBuilderDirectSwapGTest, testForNodes) {
 }
 
 TEST_P(GraphBuilderDirectSwapGTest, testParallelForNodes) {
-    std::vector<node> visited;
+    std::vector<node> visited(bHouse.upperNodeIdBound());
     this->bHouse.parallelForNodes([&](node u) {
-        #pragma omp critical
-        visited.push_back(u);
+        visited[u] = u;
     });
 
     Aux::Parallel::sort(visited.begin(), visited.end());
