@@ -45,10 +45,10 @@ protected:
     count countSelfLoopsManually(const Graph &G);
 };
 
-INSTANTIATE_TEST_CASE_P(InstantiationName, GraphGTest, testing::Values(std::make_tuple(false, false),
+INSTANTIATE_TEST_SUITE_P(InstantiationName, GraphGTest, testing::Values(std::make_tuple(false, false),
                         std::make_tuple(true, false),
                         std::make_tuple(false, true),
-                        std::make_tuple(true, true)), ); // comma required for variadic macro
+                        std::make_tuple(true, true)));
 
 bool GraphGTest::isWeighted() const { return std::get<0>(GetParam()); }
 bool GraphGTest::isDirected() const { return std::get<1>(GetParam()); }
@@ -1342,10 +1342,9 @@ TEST_P(GraphGTest, testForNodes) {
 }
 
 TEST_P(GraphGTest, testParallelForNodes) {
-    std::vector<node> visited;
+    std::vector<node> visited(Ghouse.upperNodeIdBound());
     this->Ghouse.parallelForNodes([&](node u) {
-#pragma omp critical
-        visited.push_back(u);
+        visited[u] = u;
     });
 
     Aux::Parallel::sort(visited.begin(), visited.end());
