@@ -7,12 +7,15 @@
 
 // networkit-format
 
+#include <array>
+
 #include <gtest/gtest.h>
 
 #include <networkit/auxiliary/Random.hpp>
 #include <networkit/generators/ErdosRenyiGenerator.hpp>
 #include <networkit/graph/Graph.hpp>
 #include <networkit/graph/GraphTools.hpp>
+#include <networkit/io/METISGraphReader.hpp>
 
 namespace NetworKit {
 
@@ -23,11 +26,9 @@ protected:
     bool directed() const noexcept;
 };
 
-INSTANTIATE_TEST_CASE_P(
-    InstantiationName, GraphToolsGTest,
-    testing::Values(std::make_pair(false, false), std::make_pair(true, false),
-                    std::make_pair(false, true),
-                    std::make_pair(true, true)), ); // comma required for variadic macro
+INSTANTIATE_TEST_SUITE_P(InstantiationName, GraphToolsGTest,
+                         testing::Values(std::make_pair(false, false), std::make_pair(true, false),
+                                         std::make_pair(false, true), std::make_pair(true, true)));
 
 Graph GraphToolsGTest::generateRandomWeights(const Graph &G) const {
     Graph Gw(G, true, G.isDirected());
@@ -222,6 +223,33 @@ TEST_P(GraphToolsGTest, testRandomNode) {
     }
 }
 
+TEST_P(GraphToolsGTest, testRandomNodes) {
+    const count n = 20;
+    const double p = 0.01;
+
+    Aux::Random::setSeed(42, false);
+
+    auto G = ErdosRenyiGenerator(n, p, directed()).generate();
+    if (weighted()) {
+        G = Graph(G, true, G.isDirected());
+    }
+
+    count sampleAll = G.numberOfNodes();
+    std::vector<node> allSample = GraphTools::randomNodes(G, sampleAll);
+    EXPECT_EQ(allSample.size(), sampleAll);
+    EXPECT_EQ((std::unordered_set<node>{allSample.begin(), allSample.end()}).size(), sampleAll);
+
+    count sampleMost = 15;
+    std::vector<node> mostSample = GraphTools::randomNodes(G, sampleMost);
+    EXPECT_EQ(mostSample.size(), sampleMost);
+    EXPECT_EQ((std::unordered_set<node>{mostSample.begin(), mostSample.end()}).size(), sampleMost);
+
+    count sampleSome = 5;
+    std::vector<node> someSample = GraphTools::randomNodes(G, sampleSome);
+    EXPECT_EQ(someSample.size(), sampleSome);
+    EXPECT_EQ((std::unordered_set<node>{someSample.begin(), someSample.end()}).size(), sampleSome);
+}
+
 TEST_P(GraphToolsGTest, testRandomNeighbor) {
     constexpr count n = 10;
     auto G = Graph(n, weighted(), directed());
@@ -647,9 +675,11 @@ TEST_P(GraphToolsGTest, testSubgraphFromNodesUndirected) {
     G.addEdge(3, 2, 5.0);
     G.addEdge(1, 2, 3.0);
 
-    {
+    std::array<bool, 2> compactOptions{{true, false}};
+
+    for (bool compact : compactOptions) {
         std::unordered_set<node> nodes = {0};
-        auto res = GraphTools::subgraphFromNodes(G, nodes);
+        auto res = GraphTools::subgraphFromNodes(G, nodes.begin(), nodes.end(), compact);
         EXPECT_EQ(weighted(), res.isWeighted());
         EXPECT_FALSE(res.isDirected());
         EXPECT_EQ(res.numberOfNodes(), 1);
@@ -658,7 +688,7 @@ TEST_P(GraphToolsGTest, testSubgraphFromNodesUndirected) {
 
     {
         std::unordered_set<node> nodes = {0};
-        auto res = GraphTools::subgraphFromNodes(G, nodes, true);
+        auto res = GraphTools::subgraphAndNeighborsFromNodes(G, nodes, true);
 
         EXPECT_EQ(res.numberOfNodes(), 3);
         EXPECT_EQ(res.numberOfEdges(), 2); // 0-1, 0-2, NOT 1-2
@@ -667,19 +697,28 @@ TEST_P(GraphToolsGTest, testSubgraphFromNodesUndirected) {
         EXPECT_DOUBLE_EQ(G.weight(0, 2), weighted() ? 2.0 : defaultEdgeWeight);
     }
 
-    {
+    for (bool compact : compactOptions) {
         std::unordered_set<node> nodes = {0, 1};
-        auto res = GraphTools::subgraphFromNodes(G, nodes);
+        auto res = GraphTools::subgraphFromNodes(G, nodes.begin(), nodes.end(), compact);
         EXPECT_EQ(res.numberOfNodes(), 2);
         EXPECT_EQ(res.numberOfEdges(), 1); // 0 - 1
     }
 
     {
         std::unordered_set<node> nodes = {0, 1};
-        auto res = GraphTools::subgraphFromNodes(G, nodes, true);
+        auto res = GraphTools::subgraphAndNeighborsFromNodes(G, nodes, true);
         EXPECT_EQ(res.numberOfNodes(), 4);
         EXPECT_EQ(res.numberOfEdges(), 4); // 0-1, 0-2, 1-2, 1-3
     }
+
+    G.addEdge(0, 0);
+
+    for (bool compact : compactOptions) {
+        std::unordered_set<node> nodes = {0, 1};
+        auto res = GraphTools::subgraphFromNodes(G, nodes.begin(), nodes.end(), compact);
+        EXPECT_EQ(res.numberOfNodes(), 2);
+        EXPECT_EQ(res.numberOfEdges(), 2); // 0 - 1, 0 - 0
+    }
 }
 
 TEST_P(GraphToolsGTest, testSubgraphFromNodesDirected) {
@@ -699,41 +738,49 @@ TEST_P(GraphToolsGTest, testSubgraphFromNodesDirected) {
     G.addEdge(3, 2, 5.0);
     G.addEdge(1, 2, 3.0);
 
-    {
+    std::array<bool, 2> compactOptions{{true, false}};
+
+    for (bool compact : compactOptions) {
         std::unordered_set<node> nodes = {0};
-        auto res = GraphTools::subgraphFromNodes(G, nodes);
+        auto res = GraphTools::subgraphFromNodes(G, nodes.begin(), nodes.end(), compact);
 
         EXPECT_EQ(weighted(), res.isWeighted());
         EXPECT_TRUE(res.isDirected());
 
         EXPECT_EQ(res.numberOfNodes(), 1);
         EXPECT_EQ(res.numberOfEdges(), 0);
+
+        if (compact) {
+            EXPECT_EQ(res.upperNodeIdBound(), 1);
+        } else {
+            EXPECT_EQ(res.upperNodeIdBound(), G.upperNodeIdBound());
+        }
     }
 
     {
         std::unordered_set<node> nodes = {0};
-        auto res = GraphTools::subgraphFromNodes(G, nodes, true);
+        auto res = GraphTools::subgraphAndNeighborsFromNodes(G, nodes, true);
         EXPECT_EQ(res.numberOfNodes(), 3);
         EXPECT_EQ(res.numberOfEdges(), 2); // 0->1, 0->2, NOT 1->2
     }
 
-    {
+    for (bool compact : compactOptions) {
         std::unordered_set<node> nodes = {0, 1};
-        auto res = GraphTools::subgraphFromNodes(G, nodes);
+        auto res = GraphTools::subgraphFromNodes(G, nodes.begin(), nodes.end(), compact);
         EXPECT_EQ(res.numberOfNodes(), 2);
         EXPECT_EQ(res.numberOfEdges(), 1); // 0 -> 1
     }
 
     {
         std::unordered_set<node> nodes = {0, 1};
-        auto res = GraphTools::subgraphFromNodes(G, nodes, true);
+        auto res = GraphTools::subgraphAndNeighborsFromNodes(G, nodes, true);
         EXPECT_EQ(res.numberOfNodes(), 3);
         EXPECT_EQ(res.numberOfEdges(), 3); // 0->1, 0->2, 1->2
     }
 
     {
         std::unordered_set<node> nodes = {0, 1};
-        auto res = GraphTools::subgraphFromNodes(G, nodes, true, true);
+        auto res = GraphTools::subgraphAndNeighborsFromNodes(G, nodes, true, true);
         EXPECT_EQ(res.numberOfNodes(), 4);
         EXPECT_EQ(res.numberOfEdges(), 4); // 0->1, 0->2, 1->2, 3->1
     }
@@ -938,4 +985,44 @@ TEST_P(GraphToolsGTest, testMerge) {
     }
 }
 
+TEST_P(GraphToolsGTest, testEdgesSortedByWeight) {
+    const auto hasEdgesSortedByWeight = [](const Graph &G, bool decreasing) -> bool {
+        for (node u : G.nodeRange()) {
+            node prevNode = decreasing ? none : 0;
+            edgeweight prevWeight =
+                (decreasing ? 1. : -1.) * std::numeric_limits<edgeweight>::max();
+            bool sorted = true;
+            G.forNeighborsOf(u, [&](node v, edgeweight ew) {
+                if (ew == prevWeight)
+                    sorted = prevNode <= v;
+                else
+                    sorted = decreasing ? ew < prevWeight : ew > prevWeight;
+                prevNode = v;
+                prevWeight = ew;
+            });
+
+            if (!sorted)
+                return false;
+        }
+
+        return true;
+    };
+
+    for (int seed : {1, 2, 3}) {
+        Aux::Random::setSeed(seed, true);
+        auto G = METISGraphReader{}.read("input/PGPgiantcompo.graph");
+
+        if (weighted()) {
+            G = GraphTools::toWeighted(G);
+            G.forEdges([&G](node u, node v) { G.setWeight(u, v, Aux::Random::real(10)); });
+        }
+
+        GraphTools::sortEdgesByWeight(G);
+        EXPECT_TRUE(hasEdgesSortedByWeight(G, false));
+        EXPECT_TRUE(G.checkConsistency());
+        GraphTools::sortEdgesByWeight(G, true);
+        EXPECT_TRUE(hasEdgesSortedByWeight(G, true));
+        EXPECT_TRUE(G.checkConsistency());
+    }
+}
 } // namespace NetworKit
