@@ -1,13 +1,16 @@
-#include <networkit/io/BinaryEdgeListPartitionWriter.hpp>
 #include <fstream>
 
-NetworKit::BinaryEdgeListPartitionWriter::BinaryEdgeListPartitionWriter(NetworKit::node firstNode, uint8_t width) : firstNode(firstNode), width(width) {
+#include <networkit/io/BinaryEdgeListPartitionWriter.hpp>
+
+namespace NetworKit {
+
+BinaryEdgeListPartitionWriter::BinaryEdgeListPartitionWriter(node firstNode, uint8_t width) : firstNode(firstNode), width(width) {
     if (width != 4 && width != 8) {
         throw std::runtime_error("Width must be 4 or 8");
     }
 }
 
-void NetworKit::BinaryEdgeListPartitionWriter::write( NetworKit::Partition &zeta, const std::string &path ) const {
+void BinaryEdgeListPartitionWriter::write( Partition &zeta, const std::string &path ) const {
     auto write_little_endian = [](std::ofstream &os, index x, uint8_t width) {
         for (uint8_t w = 0; w < width; ++w) {
             os.put(uint8_t(x));
@@ -23,8 +26,10 @@ void NetworKit::BinaryEdgeListPartitionWriter::write( NetworKit::Partition &zeta
 
     os.exceptions(std::ofstream::badbit | std::ofstream::failbit);
 
-    zeta.forEntries([&](NetworKit::index u, NetworKit::index p) {
+    zeta.forEntries([&](index u, index p) {
         write_little_endian(os, u + firstNode, width);
         write_little_endian(os, p, width);
     });
 }
+
+} // namespace NetworKit
