@@ -28,7 +28,7 @@ std::map<index, double> DotPartitionWriter::createHueMap(Graph &graph, Partition
     return clusterHueMap;
 }
 
-void DotPartitionWriter::write(Graph& graph, Partition& zeta, std::string path) const {
+void DotPartitionWriter::write(Graph &graph, Partition &zeta, const std::string &path) const {
     std::ofstream file{path};
 
     auto hueMap = this->createHueMap(graph, zeta);
