@@ -17,10 +17,9 @@ void GraphIO::writeEdgeList(const Graph &G, const std::string &path) {
     std::ofstream file;
     file.open(path.c_str());
 
-    G.forEdges([&](const node v, const node w) { file << v << " " << w << std::endl; });
+    G.forEdges([&](const node v, const node w) { file << v << " " << w << '\n'; });
 
     file.close();
-    INFO("wrote graph to file: ", path);
 }
 
 void GraphIO::writeAdjacencyList(const Graph &G, const std::string &path) {
@@ -30,9 +29,8 @@ void GraphIO::writeAdjacencyList(const Graph &G, const std::string &path) {
     G.forNodes([&](const node v) {
         file << v;
         G.forNeighborsOf(v, [&](const node x) { file << " " << x; });
-        file << std::endl;
+        file << '\n';
     });
-    INFO("wrote graph to file: ", path);
 }
 
 } /* namespace NetworKit */
