@@ -1,5 +1,5 @@
 /*
- * MatrixMarketReader.cpp
+ *  MatrixMarketReader.cpp
  *
  *  Created on: 25.07.2014
  *      Author: dhoske
@@ -26,7 +26,7 @@ namespace {
 
 CSRMatrix MatrixMarketReader::read(const std::string &path) {
     std::ifstream in(path);
-    if (!in) {
+    if (!in.is_open()) {
         throw std::runtime_error("could not open: " + path);
     }
     return read(in);
@@ -35,7 +35,7 @@ CSRMatrix MatrixMarketReader::read(const std::string &path) {
 CSRMatrix MatrixMarketReader::read(std::istream& in) {
     enum { FIRST_LINE, HEADER, ENTRIES } state = FIRST_LINE;
 
-    count nrows, ncols, nzeroes;
+    count nrows = 0, ncols = 0, nzeroes;
     std::vector<Triplet> triplets;
     std::string line;
     bool weighted = true;
