@@ -15,7 +15,8 @@ namespace NetworKit {
 
 namespace LinkThresholder {
 
-std::vector<std::pair<node, node>> byScore(std::vector<LinkPredictor::prediction> predictions, double minScore) {
+std::vector<std::pair<node, node>>
+byScore(const std::vector<LinkPredictor::prediction> &predictions, double minScore) {
   std::list<LinkPredictor::prediction> predictionsList;
   std::copy(predictions.begin(), predictions.end(), std::back_inserter(predictionsList));
   predictionsList.erase(std::remove_if(predictionsList.begin(), predictionsList.end(),
@@ -28,12 +29,15 @@ std::vector<std::pair<node, node>> byScore(std::vector<LinkPredictor::prediction
   return selectedLinks;
 }
 
-std::vector<std::pair<node, node>> byCount(std::vector<LinkPredictor::prediction> predictions, count numLinks) {
+std::vector<std::pair<node, node>>
+byCount(const std::vector<LinkPredictor::prediction> &predictions, count numLinks) {
   if (numLinks > predictions.size()) {
     throw std::invalid_argument("numLinks > predictions.size().");
   }
-  PredictionsSorter::sortByScore(predictions);
-  std::vector<LinkPredictor::prediction> selectedPredictions(predictions.begin(), predictions.begin() + numLinks);
+  auto sortedPredictions = predictions;
+  PredictionsSorter::sortByScore(sortedPredictions);
+  std::vector<LinkPredictor::prediction> selectedPredictions(sortedPredictions.begin(),
+                                                             sortedPredictions.begin() + numLinks);
   std::vector<std::pair<node, node>> selectedLinks;
   selectedLinks.reserve(selectedPredictions.size());
   std::transform(selectedPredictions.begin(), selectedPredictions.end(), std::back_inserter(selectedLinks),
@@ -42,11 +46,12 @@ std::vector<std::pair<node, node>> byCount(std::vector<LinkPredictor::prediction
   return selectedLinks;
 }
 
-std::vector<std::pair<node, node>> byPercentage(std::vector<LinkPredictor::prediction> predictions, double percentageLinks) {
-  if (percentageLinks < 0 || percentageLinks > 1) {
-    throw std::invalid_argument("Given percentage is not in [0, 1].");
-  }
-  return byCount(predictions, percentageLinks * predictions.size());
+std::vector<std::pair<node, node>>
+byPercentage(const std::vector<LinkPredictor::prediction> &predictions, double percentageLinks) {
+    if (percentageLinks < 0 || percentageLinks > 1) {
+        throw std::invalid_argument("Given percentage is not in [0, 1].");
+    }
+    return byCount(predictions, percentageLinks * predictions.size());
 }
 
 } // namespace LinkThresholder
