@@ -9,18 +9,15 @@
 
 namespace NetworKit {
 
-RandomEdgeScore::RandomEdgeScore(const Graph& G) : EdgeScore<double>(G) {
-}
+RandomEdgeScore::RandomEdgeScore(const Graph& G) : EdgeScore<double>(G) {}
 
 void RandomEdgeScore::run() {
-    if (!G.hasEdgeIds()) {
+    if (!G->hasEdgeIds()) {
         throw std::runtime_error("edges have not been indexed - call indexEdges first");
     }
-    scoreData.resize(G.upperEdgeIdBound(), 0.0);
+    scoreData.resize(G->upperEdgeIdBound(), 0.0);
 
-    G.parallelForEdges([&](node, node, edgeid eid) {
-        //double r = Aux::Random::probability();
-        //scoreData[eid] = randomness * r + (1 - randomness) * attribute[eid];
+    G->parallelForEdges([&](node, node, edgeid eid) {
         scoreData[eid] = Aux::Random::probability();
     });
     hasRun = true;
