@@ -6,10 +6,12 @@
  */
 
 #include <cmath>
+#include <limits>
 #include <queue>
 
 #include <networkit/auxiliary/Log.hpp>
 #include <networkit/auxiliary/PrioQueue.hpp>
+#include <networkit/auxiliary/Timer.hpp>
 #include <networkit/components/ConnectedComponents.hpp>
 #include <networkit/distance/BFS.hpp>
 #include <networkit/distance/Dijkstra.hpp>
@@ -521,7 +523,7 @@ void MaxentStress::addKNeighborhoodOfVertex(const node u, const count k) {
 
         dist[u] = 0;
         PQ.insert(0, u);
-        while (PQ.size() > 0 && numVerticesToVisit > 0) {
+        while (!PQ.empty() && numVerticesToVisit > 0) {
             node v = PQ.extractMin().second;
             if (1 < depth[v] && depth[v] <= k) {
                 knownDistances[u].push_back({v, dist[v]});
