@@ -5,6 +5,8 @@
  *      Author: Michael Wegner
  */
 
+#include <limits>
+
 #include <networkit/auxiliary/PrioQueue.hpp>
 #include <networkit/auxiliary/Random.hpp>
 #include <networkit/graph/GraphTools.hpp>
@@ -12,12 +14,16 @@
 
 namespace NetworKit {
 
-PivotMDS::PivotMDS(const Graph &graph, count dim, count numPivots)
-    : GraphLayoutAlgorithm(graph, dim), dim(dim), numPivots(numPivots) {}
+PivotMDS::PivotMDS(const Graph &G, count dim, count numPivots)
+    : GraphLayoutAlgorithm(G, dim), dim(dim), numPivots(numPivots) {}
 
 void PivotMDS::run() {
     count n = G->numberOfNodes();
-    std::vector<node> pivots = computePivots();
+    if (n < numPivots) {
+        WARN("Number of Pivots higher than the number of nodes. Setting number of pivots to number of nodes");
+        numPivots = n;
+    }
+    std::vector<node> pivots = GraphTools::randomNodes(*G, numPivots);
 
     std::vector<Triplet> triplets;
     for (index j = 0; j < numPivots;
@@ -27,7 +33,7 @@ void PivotMDS::run() {
 
         dist[pivots[j]] = 0;
         PQ.insert(0, pivots[j]);
-        while (PQ.size() > 0) {
+        while (!PQ.empty()) {
             node v = PQ.extractMin().second;
             triplets.push_back({v, j, dist[v]});
             G->forNeighborsOf(v, [&](node w, edgeweight weight) {
@@ -102,23 +108,6 @@ void PivotMDS::run() {
     }
 }
 
-std::vector<node> PivotMDS::computePivots() {
-    count n = G->numberOfNodes();
-    std::vector<bool> pivot(n, false);
-    std::vector<node> pivots(numPivots);
-
-    index pivotIdx = 0;
-    while (pivotIdx < numPivots) {
-        node pivotCandidate = GraphTools::randomNode(*G);
-        if (!pivot[pivotCandidate]) {
-            pivots[pivotIdx++] = pivotCandidate;
-            pivot[pivotCandidate] = true;
-        }
-    }
-
-    return pivots;
-}
-
 void PivotMDS::powerMethod(const CSRMatrix &mat, count n,
                            Vector &eigenvector, double &eigenvalue) {
     eigenvector = Vector(n);
