@@ -6,8 +6,8 @@ from .distance import APSP
 def graphFromStream(stream, weighted, directed):
 	""" Convenience function for creating a new graph from a stream of graph events
 
-	Parameters
-	----------
+	Parameters:
+	-----------
 	stream : list of GraphEvent
 		event stream
 	weighted : produce a weighted or unweighted graph
