@@ -18,7 +18,8 @@ class TestGraphTools(unittest.TestCase):
 	def generateRandomWeights(self, G):
 		if not G.isWeighted():
 			G = nk.graphtools.toWeighted(G)
-		G.forEdges(lambda u, v, w, eid: G.setWeight(u, v, random.random()))
+		for e in G.iterEdges():
+			G.setWeight(e[0], e[1], random.random())
 
 		return G
 
@@ -199,7 +200,7 @@ class TestGraphTools(unittest.TestCase):
 		self.assertEqual(res.numberOfNodes(), 1)
 		self.assertEqual(res.numberOfEdges(), 0)
 
-		res = nk.graphtools.subgraphFromNodes(G, nodes, True)
+		res = nk.graphtools.subgraphAndNeighborsFromNodes(G, nodes, True)
 
 		self.assertEqual(res.numberOfNodes(), 3)
 		self.assertEqual(res.numberOfEdges(), 2) # 0-1, 0-2, NOT 1-2
@@ -212,7 +213,7 @@ class TestGraphTools(unittest.TestCase):
 		self.assertEqual(res.numberOfNodes(), 2)
 		self.assertEqual(res.numberOfEdges(), 1) # 0 - 1
 
-		res = nk.graphtools.subgraphFromNodes(G, nodes, True)
+		res = nk.graphtools.subgraphAndNeighborsFromNodes(G, nodes, True)
 		self.assertEqual(res.numberOfNodes(), 4)
 		self.assertEqual(res.numberOfEdges(), 4) # 0-1, 0-2, 1-2, 1-3
 
@@ -229,7 +230,7 @@ class TestGraphTools(unittest.TestCase):
 		self.assertEqual(res.numberOfEdges(), 0)
 
 		nodes = set([0])
-		res = nk.graphtools.subgraphFromNodes(G, nodes, True)
+		res = nk.graphtools.subgraphAndNeighborsFromNodes(G, nodes, True)
 		self.assertEqual(res.numberOfNodes(), 3)
 		self.assertEqual(res.numberOfEdges(), 2) # 0->1, 0->2, NOT 1->2
 
@@ -239,12 +240,12 @@ class TestGraphTools(unittest.TestCase):
 		self.assertEqual(res.numberOfEdges(), 1) # 0 -> 1
 
 		nodes = set([0, 1])
-		res = nk.graphtools.subgraphFromNodes(G, nodes, True)
+		res = nk.graphtools.subgraphAndNeighborsFromNodes(G, nodes, True)
 		self.assertEqual(res.numberOfNodes(), 3)
 		self.assertEqual(res.numberOfEdges(), 3) # 0->1, 0->2, 1->2
 
 		nodes = set([0, 1])
-		res = nk.graphtools.subgraphFromNodes(G, nodes, True, True)
+		res = nk.graphtools.subgraphAndNeighborsFromNodes(G, nodes, True, True)
 		self.assertEqual(res.numberOfNodes(), 4)
 		self.assertEqual(res.numberOfEdges(), 4) # 0->1, 0->2, 1->2, 3->1
 
@@ -454,5 +455,46 @@ class TestGraphTools(unittest.TestCase):
 				nk.graphtools.removeEdgesFromIsolatedSet(G, [3, 4, 5])
 				self.assertEqual(G.numberOfEdges(), 0)
 
+	def testSortEdgesByWeight(self):
+		def checkSortedEdges(g, decreasing):
+			for u in g.iterNodes():
+				prevNode = g.numberOfNodes() if decreasing else -1
+				prevWeight = 2 if decreasing else 0
+
+				for v in g.iterNeighbors(u):
+					w = g.weight(u, v)
+					if decreasing:
+						if w == prevWeight:
+							self.assertLess(prevNode, v)
+						else:
+							self.assertLess(w, prevWeight)
+					else:
+						if w == prevWeight:
+							self.assertLess(prevNode, v)
+						else:
+							self.assertGreater(w, prevWeight)
+
+					prevNode, prevWeight = v, w
+
+		def doTest(g):
+			nk.graphtools.sortEdgesByWeight(g, False)
+			checkSortedEdges(g, False)
+			nk.graphtools.sortEdgesByWeight(g, True)
+			checkSortedEdges(g, True)
+
+		g = nk.readGraph('input/PGPgiantcompo.graph', nk.Format.METIS)
+		g.removeSelfLoops()
+		g.removeMultiEdges()
+
+		# Test unweighted
+		doTest(g)
+
+		random.seed(1)
+		g = self.generateRandomWeights(g)
+		e = nk.graphtools.randomEdge(g)
+
+		# Test weighted
+		doTest(g)
+
 if __name__ == "__main__":
 	unittest.main()
